library(readr)
library(effsize)

#Read Performance Data
inter_performance_pre <- read_csv("performance_data_intervention_pre.csv") 
inter_performance_post <- read_csv("performance_data_intervention_post.csv")  

control_performance_pre <- read_csv("performance_data_control_pre.csv") 
control_performance_post <- read_csv("performance_data_control_post.csv")  


# Step 1: Calculate Deltas
inter_performance_deltas <- inter_performance_post$`Performance Data` - inter_performance_pre$`Performance Data`
control_performance_deltas <- control_performance_post$`Performance Data` - control_performance_pre$`Performance Data`

# Step 2: Perform Independent t-test on the Deltas
t_test_result_performance <- t.test(inter_performance_deltas, control_performance_deltas, paired = FALSE)

cohen_d_performance <- cohen.d(inter_performance_deltas, control_performance_deltas, pooled = TRUE)
print(cohen_d_performance)

# Calculate SD of Deltas
sd_inter_performance_deltas <- sd(inter_performance_deltas)
sd_control_performance_deltas <- sd(control_performance_deltas)

print(paste("SD Intervention Performance Deltas:", sd_inter_performance_deltas))
print(paste("SD Control Performance Deltas:", sd_control_performance_deltas))

# Calculate Correlation for Performance Data
correlation_performance <- cor(inter_performance_deltas, control_performance_deltas)
print(paste("Correlation (Performance):", correlation_performance))

#Read Self-Efficacy Data
inter_SE_pre <- read_csv("averages_SE_intervention_pre.csv") 
inter_SE_post <- read_csv("averages_SE_intervention_post.csv")  

control_SE_pre <- read_csv("averages_SE_control_pre.csv") 
control_SE_post <- read_csv("averages_SE_control_post.csv")  


# Step 1: Calculate Deltas
inter_SE_deltas <- inter_SE_post$`P_Average` - inter_SE_pre$`P_Average`
control_SE_deltas <- control_SE_post$`P_Average` - control_SE_pre$`P_Average`

# Step 2: Perform Independent t-test on the Deltas
t_test_result_SE<- t.test(inter_SE_deltas, control_SE_deltas, paired = FALSE)

cohen_d_SE <- cohen.d(inter_SE_deltas, control_SE_deltas, pooled = TRUE)
print(cohen_d_SE)

# Calculate SD of Deltas
sd_inter_SE_deltas <- sd(inter_SE_deltas)
sd_control_SE_deltas <- sd(control_SE_deltas)

print(paste("SD Intervention SE Deltas:", sd_inter_SE_deltas))
print(paste("SD Control SE Deltas:", sd_control_SE_deltas))

# Calculate Correlation for Self-Efficacy Data
correlation_SE <- cor(inter_SE_deltas, control_SE_deltas)
print(paste("Correlation (Self-Efficacy):", correlation_SE))

#Read Perceived Usefulness Data
inter_PU <- read_csv("averages_PU_intervention.csv") 
control_PU <- read_csv("averages_PU_control.csv")  

# Step 2: Perform Independent t-test on the Deltas
t_test_result_PU<- t.test(inter_PU$`P_Average`, control_PU$`P_Average`, paired = FALSE)

# Step 3: Calculate Cohen's d for Perceived Usefulness
cohen_d_PU <- cohen.d(inter_PU$`P_Average`, control_PU$`P_Average`, pooled = TRUE)
print(cohen_d_PU)

# Calculate SD for Perceived Usefulness
sd_inter_PU <- sd(inter_PU$`P_Average`)
sd_control_PU <- sd(control_PU$`P_Average`)

print(paste("SD Intervention PU:", sd_inter_PU))
print(paste("SD Control PU:", sd_control_PU))

# Calculate Correlation for Perceived Usefulness
correlation_PU <- cor(inter_PU$`P_Average`, control_PU$`P_Average`)
print(paste("Correlation (Perceived Usefulness):", correlation_PU))

# Print the result
print(t_test_result_performance)

# Print the result
print(t_test_result_SE)

# Print the result
print(t_test_result_PU)

average_correlation <- mean(correlation_performance, correlation_SE,correlation_PU)
# Extract the d estimates from the Cohen's d objects
d_performance <- cohen_d_performance$estimate
d_SE <- cohen_d_SE$estimate
d_PU <- cohen_d_PU$estimate

# Calculate the average effect size
average_effect_size <- mean(c(d_performance, d_SE, d_PU))


print(average_correlation)
print(average_effect_size)
