# The following code is based on a similar code  by Willem-Paul Brinkman.

# Load necessary libraries
set.seed(123)  # For reproducibility

#largest effect size
#power same as before

# Constants
n_participants <- 54# Number of participants
n_simulations <- 1000  # Number of simulations
correlation <- -0.36  # Correlation between baseline and post
R_squared <- correlation^2  # Calculate R-square
effect_size <- 0.62  # Effect size

# Helper function to generate results
generate_condition <- function(n_participants, n_simulations, R_squared, effect_size = 0) {
  # Baseline
  baseline <- matrix(rnorm(n_participants * n_simulations, mean = 0, sd = 1), 
                     nrow = n_simulations, ncol = n_participants)
  
  # Post
  post <- baseline * R_squared + 
    matrix(rnorm(n_participants * n_simulations, mean = 0, sd = 1), 
           nrow = n_simulations, ncol = n_participants) * (1 - R_squared)
  
  # Apply effect size adjustment for post if provided
  post <- post + effect_size
  
  # Delta (Post - Baseline)
  delta <- post - baseline
  
  return(list(baseline = baseline, post = post, delta = delta))
}

# Generate results for Condition A
condition_A <- generate_condition(n_participants, n_simulations, R_squared)

# Generate results for Condition B (with effect size adjustment)
condition_B <- generate_condition(n_participants, n_simulations, R_squared, effect_size)

# Example Outputs
cat("Condition A Delta:\n")
print(condition_A$delta[1:5, ])  # Show the first 5 deltas for Condition A

cat("\nCondition B Delta:\n")
print(condition_B$delta[1:5, ])  # Show the first 5 deltas for Condition B

mean_delta_A <- apply(condition_A$delta, 1, mean)
mean_delta_B <- apply(condition_B$delta, 1, mean)

cat("Mean Delta for Condition A (first 10 simulations):\n", head(mean_delta_A, 10), "\n")
cat("Mean Delta for Condition B (first 10 simulations):\n", head(mean_delta_B, 10), "\n")

# Constants
alpha <- 0.05  # Significance level

# Perform t-tests for each simulation
p_values <- sapply(1:n_simulations, function(i) {
  t_test <- t.test(condition_A$delta[i, ], condition_B$delta[i, ])
  return(t_test$p.value)
})

# Count p-values less than alpha
significant_tests <- sum(p_values < alpha)

# Calculate power
power <- significant_tests / n_simulations

# Output results
cat("Number of significant tests (p < 0.05):", significant_tests, "\n")
cat("Statistical Power:", power, "\n")


