# Evaluation of Pedagogical Agent Integration Into Simulation Training For Child Helplines.
Authors: Maya Elasmar

Contact: M.ELasmar@student.tudelft.nl

This dataset is created as part of an evaluation study of a pedagogical agent integration into a simulation training for Child Helplines. The design of this evaluation study was pre-registered under the Open Science Framework (OSF) registries and is publicly available at https://osf.io/9gtbm. The dataset contains participants' perfromance and survey responses with regards to the measures - performance during interaction with virtual child, counselling self-efficacy and perceived usefulness of the agent. The markdown script contains data-specific information on how to make use of this dataset. The data was collected through an online survey hosted on Qualtrics.  The questionnaires for the surveys mentioned below can be found in the appendices of the main thesis report: ....

All statistical analyses were done using R software (version 4.3.0). This work is licensed under CC BY 4.0

The original data files used in the data cleaning files contain confidential data, hence they were not published.

## Files:
- Experiment Analysis.Rmd: The markdown file conatining all the analysis of this project. To run it you only need the csv files.
- Experiment-Analysis.Pdf: The Pdf file of the previous markdown "Experiment Analysis.Rmd".
- Original Power Calculation.R: The script of the power analysis to calculate the sample size in R
- Projected Power Calculation.R: The script of the power analysis to calculate the sample size knowing the correlation and the effect size in R
- Experiment t-test Analysis.R: Script for data analysis in R
- Cohens Kappa.R: Script for double Coding interreliability Analysis in R
- Responses Coders Assignment.csv: The coders themes assignment to the the respones of the open questions.
- performance_data_control_pre.csv: The averages of performance of each participant of the control group in the pre-session.
- performance_data_control_post.csv: The averages of performance of each participant of the control group in the post-session.
- performance_data_intervention_pre.csv: The averages of performance of each participant of the intervention group in the pre-session.
- performance_data_intervention_post.csv: The averages of performance of each participant of the intervention group in the post-session.
- average_SE_control_pre.csv: The averages of self-efficacy scores of each participant of the control group in the pre-session.
- average_SE_control_post.csv: The averages of self-efficacy scores of each participant of the control group in the post-session.
- average_SE_intervention_pre.csv: The averages of self-efficacy scores of each participant of the intervention group in the pre-session.
- average_SE_intervention_post.csv: The averages of self-efficacy scores of each participant of the intervention group in the post-session.
- averages_PU_control.csv: The averages of perceived usefuleness scores of each participant of the control group.
- averages_PU_intervention.csv: The averages of perceived usefuleness scores of each participant of the intervention group.
- Experiment_Data.ipynb: The python notebook that contains the data cleaning of the qualtrics Data and visaulization of the data with graphs.
- Intervention_Performance.ipynb: The python notebook that containes the data cleaning of the performance data of the intervention group.
- Control_Performance.ipynb: The python notebook that containes the data cleaning of the performance data of the control group.

## The csv files contain these columns:
### Perfromance Results
- Participant ID: The participant ID corresponding to the average performance.
- Performance Data: Average Performance for certain participant

### Self-Efficacy Results:
#### average_SE_control_pre.csv:
- Participant ID: The participant ID corresponding to the average score.
- Q28_1 - Q37_1 : Items of Self-Efficiacy pre-questionnaire
- P_Average: Average Self-Efficacy results for certain participant

#### average_SE_control_post.csv:
- Participant ID: The participant ID corresponding to the average score.
- Q61_1 - Q53_1 : Items of Self-Efficiacy post-questionnaire
- P_Average: Average Self-Efficacy results for certain participant

#### average_SE_intervention_pre.csv:
- Participant ID: The participant ID corresponding to the average score.
- Q28_1 - Q37_1 : Items of Self-Efficiacy pre-questionnaire
- P_Average: Average Self-Efficacy results for certain participant

#### average_SE_intervention_post.csv:
- Participant ID: The participant ID corresponding to the average score.
- Q61_1 - Q53_1 : Items of Self-Efficiacy post-questionnaire
- P_Average: Average Self-Efficacy results for certain participant

### Perceived Usefulness Results:
#### averages_PU_control.csv:
- Q25: Randomly generated id of the participants
- Q50_1 - Q55_1.1: Items of Perceived Usefulness questionnaire
- P_Average: Average Perceived Usefulness results for certain participant

#### averages_PU_intervention.csv:
- Q25: Randomly generated id of the participants
- Q50_1 - Q55_1.1: Items of Perceived Usefulness questionnaire
- P_Average: Average Perceived Usefulness results for certain participant

### Responses Coders Assignment:
- Responses: The responses of both groups and both questions: (2-23) responses of Q1: "What did you like the most about our system?", (24-46) responses of Q2: "What did you like the least about our system?"
- Coder 1: The assignments of the first Coder
- Coder 2: The assignments of the second Coder
- Common Ground: The assignments of both coders after discussion

